from PIL import Image, ImageFont, ImageDraw
import click
import os
import random


def set_random_color() -> tuple[int, int, int]:

    def rand_col(num: int):
        num = random.randint(0, 255)
        return num

    r = 0
    g = 0
    b = 0

    color = [r, g, b]
    color = list(map(rand_col, color))
    return tuple(color)


def divLine(txt: str) -> tuple[str, str]:
    if len(txt) != 4:
        raise ValueError

    line = []
    line2 = []

    for i, c in enumerate(txt):
        if i == 0 or i == 2:
            line.append(c)
        else:
            line2.append(c)

    line.reverse()
    line2.reverse()

    lineTxt = "".join(line)
    lineTxt2 = "".join(line2)

    return (lineTxt, lineTxt2)


def to_tuple(txt: str) -> tuple[int, ...]:
    str_list = txt.split(",")
    int_list = list(map(int, str_list))

    try:
        int_list = list(map(int, str_list))

    except ValueError:
        raise ValueError("数値に変換できない要素が渡されました。")
        os.exit(1)

    if len(int_list) != 3:
        raise ValueError("渡された文字列の書式が不正です。")
        os.exit(1)

    int_tuple = tuple(int_list)

    return int_tuple


@click.command()
@click.argument("text")
@click.option('--color', help='set color', default="0, 0, 0")
# @click.argument("text")
def main(text: str, color: str = "0, 0, 0"):
    font_path = "rounded-x-mplus-1c-bold.ttf"
    font_size = 100

    tup_color = to_tuple(color)
    text, text2 = divLine(text)

    if color == "0, 0, 0":
        tup_color = set_random_color()

    # color = (255, 255, 255)
    # color = (0, 0, 0)
    # blue  = (131, 217, 242)

    image = Image.new("RGB", (200, 200), (255, 255, 255))

    font = ImageFont.truetype(font_path, font_size)
    draw = ImageDraw.Draw(image)

    draw.text((0, -20), text, font=font, fill=tup_color)
    draw.text((0, font_size - 20), text2, font=font, fill=tup_color)

    image.save("out.png")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['stampy']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=9.2.0,<10.0.0', 'click>=8.1.3,<9.0.0']

entry_points = \
{'console_scripts': ['stampy = stampy.main:main']}

setup_kwargs = {
    'name': 'stampy',
    'version': '0.1.3',
    'description': '４文字の文字列をスタンプ風画像に変換するツール ',
    'long_description': '<div align="center">\n\n![Last commit](https://img.shields.io/github/last-commit/Comamoca/stampy?style=flat-square)\n![Repository Stars](https://img.shields.io/github/stars/Comamoca/stampy?style=flat-square)\n![Issues](https://img.shields.io/github/issues/Comamoca/stampy?style=flat-square)\n![Open Issues](https://img.shields.io/github/issues-raw/Comamoca/stampy?style=flat-square)\n![Bug Issues](https://img.shields.io/github/issues/Comamoca/stampy/bug?style=flat-square)\n\n#  stampy 🍣\n\n４文字の文字列をスタンプ風の画像に変換します。\n\n![生成出来る画像の例](./out.png "生成出来る画像の例")\n\n</div>\n\n<table>\n  <thead>\n    <tr>\n      <th style="text-align:center">🍡日本語</th>\n      <th style="text-align:center">🍔Sorry, Japanease Only</th>\n    </tr>\n  </thead>\n</table>\n\n<div align="center">\n\n</div>\n\n> **Note**\n> バージョン0.1.3からデフォルトでランダムな色を生成する仕様になりました。\n> デフォルト値の黒色を利用していた方は`--color`オプションで`0,0,0`を指定してください。\n\n## 🚀 使い方\n\n```\n# 文字列を与えるとスタンプ風の画像を生成します。デフォルトでランダムな文字色になります。\nstampy にんにん\n\n# オプションで色(RGB)を指定する事ができます。\nstampy にんにん --color 100,180,123\n\n# ４文字以外の文字列はエラーになります。\nstampy にゃんにゃん\n\n# カレントディレクトリにoutput.pngという画像が出力されます。\n```\n\n## ⬇️  Install\n\n```sh\n# PyPIからでもインストール出来ます。\npipx install stampy\n\n# インストールにはpipxを推奨します。\npipx install git+https://github.com/Comamoca/stampy\n```\n\n## ⛏️   開発\n\n```sh\ngit clone https://github.com/Comamoca/stampy\ncd stampy\npoetry install\npoetry run python src/main.py\n```\n## 📝 Todo\n\nNot yet...💤\n\n## 📜 ライセンス\n\nMIT\n[SIL Open Font License](https://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL_web)\n\n### 🧩 Modules\n\n[💕 スペシャルサンクス](#💕スペシャルサンクス)\n\n## 👏 影響を受けたプロジェクト\n\nNot yet...💤\n\n## 💕 スペシャルサンクス\n\n- [M+フォント](https://mplusfonts.github.io/)\n\n- [pillow](https://github.com/python-pillow/Pillow)\n\n- [click](https://github.com/pallets/click)\n',
    'author': 'Comamoca',
    'author_email': 'comamoca.dev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
